hi_model_set_rhs: Set Right Hand Side for a Highs Model

View source: R/model-api.R

hi_model_set_rhsR Documentation

Set Right Hand Side for a Highs Model

Description

This function sets the left hand side for a given Highs model.

Usage

hi_model_set_rhs(model, rhs)

Arguments

model

an object of class "highs_model".

rhs

a numeric vector giving the left hand side values.

Value

NULL

Examples

model <- hi_new_model()
model <- hi_model_set_rhs(model, c(0, 1, 2))


highs documentation built on Feb. 8, 2026, 5:06 p.m.