hi_solver_change_constraint_bounds: Change Constraint Bounds

View source: R/solver-api.R

hi_solver_change_constraint_boundsR Documentation

Change Constraint Bounds

Description

This function updates the bounds of an existing constraint in the model.

Usage

hi_solver_change_constraint_bounds(solver, idx, lhs, rhs)

Arguments

solver

An object of class "highs_solver".

idx

An integer vector specifying the constraint indices. Note that idx starts at 0.

lhs

The new left-hand side bound.

rhs

The new right-hand side bound.

Details

This is a low-level wrapper for 'highs.changeRowsBounds' that only does basic checks to prevent segfaults, but otherwise behaves exactly like 'highs.changeRowsBounds'.

Value

The solver instance with updated constraint bounds.

Examples

solver <- example_solver()
hi_solver_change_constraint_bounds(solver, 1, -Inf, 100)


highs documentation built on June 8, 2026, 9:06 a.m.