hi_solver_set_start: Set Starting Solution for the Solver

View source: R/solver-api.R

hi_solver_set_startR Documentation

Set Starting Solution for the Solver

Description

This function sets the starting solution for the solver.

Usage

hi_solver_set_start(solver, val)

Arguments

solver

An object of class "highs_solver".

val

A numeric vector of values for the variables. Missing values can be used to specify that particular variables should have their starting values calculated automatically.

Value

An integer value indicating the status.

Examples

solver <- example_solver()
hi_solver_set_start(solver, c(0, NA, NA))


highs documentation built on June 8, 2026, 9:06 a.m.