| hi_solver_set_start | R Documentation |
This function sets the starting solution for the solver.
hi_solver_set_start(solver, val)
solver |
An object of class "highs_solver". |
val |
A numeric vector of values for the variables. Missing values can be used to specify that particular variables should have their starting values calculated automatically. |
An integer value indicating the status.
solver <- example_solver()
hi_solver_set_start(solver, c(0, NA, NA))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.