hi_solver_set_start: Set Starting Solution for the Solver
Description
This function sets the starting solution for the solver.
Usage
hi_solver_set_start(solver, val)
Value
An integer value indicating the status.
Arguments
solver
An object of class "highs_solver".
val
A numeric vector of values for the variables.
Missing values can be used to specify that particular
variables should have their starting values calculated automatically.